@@ -5,7 +5,12 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\Response;
+use PMA\libraries\Encoding;
 use PMA\libraries\plugins\ImportPlugin;
+use PMA\libraries\File;
+use PMA\libraries\URL;
+use PMA\libraries\Bookmark;
 
 /* Enable LOAD DATA LOCAL INFILE for LDI plugin */
 if (isset($_POST['format']) && $_POST['format'] == 'ldi') {
@@ -17,7 +22,6 @@ if (isset($_POST['format']) && $_POST['format'] == 'ldi') {
  */
 require_once 'libraries/common.inc.php';
 require_once 'libraries/sql.lib.php';
-require_once 'libraries/bookmark.lib.php';
 //require_once 'libraries/display_import_functions.lib.php';
 
 if (isset($_REQUEST['show_as_php'])) {
@@ -33,9 +37,10 @@ if (isset($_REQUEST['simulate_dml'])) {
     exit;
 }
 
+$response = Response::getInstance();
+
 // If it's a refresh console bookmarks request
 if (isset($_REQUEST['console_bookmark_refresh'])) {
-    $response = PMA\libraries\Response::getInstance();
     $response->addJSON(
         'console_message_bookmark', PMA\libraries\Console::getBookmarkContent()
     );
@@ -43,11 +48,10 @@ if (isset($_REQUEST['console_bookmark_refresh'])) {
 }
 // If it's a console bookmark add request
 if (isset($_REQUEST['console_bookmark_add'])) {
-    $response = PMA\libraries\Response::getInstance();
     if (isset($_REQUEST['label']) && isset($_REQUEST['db'])
         && isset($_REQUEST['bookmark_query']) && isset($_REQUEST['shared'])
     ) {
-        $cfgBookmark = PMA_Bookmark_getParams();
+        $cfgBookmark = Bookmark::getParams();
         $bookmarkFields = array(
             'bkm_database' => $_REQUEST['db'],
             'bkm_user'  => $cfgBookmark['user'],
@@ -55,7 +59,8 @@ if (isset($_REQUEST['console_bookmark_add'])) {
             'bkm_label' => $_REQUEST['label']
         );
         $isShared = ($_REQUEST['shared'] == 'true' ? true : false);
-        if (PMA_Bookmark_save($bookmarkFields, $isShared)) {
+        $bookmark = Bookmark::createBookmark($bookmarkFields, $isShared);
+        if ($bookmark !== false && $bookmark->save()) {
             $response->addJSON('message', __('Succeeded'));
             $response->addJSON('data', $bookmarkFields);
             $response->addJSON('isShared', $isShared);
@@ -86,7 +91,6 @@ $post_params = array(
     'local_import_file'
 );
 
-// TODO: adapt full list of allowed parameters, as in export.php
 foreach ($post_params as $one_post_param) {
     if (isset($_POST[$one_post_param])) {
         $GLOBALS[$one_post_param] = $_POST[$one_post_param];
@@ -113,7 +117,8 @@ if (! empty($sql_query)) {
     // apply values for parameters
     if (! empty($_REQUEST['parameterized'])
         && ! empty($_REQUEST['parameters'])
-        && is_array($_REQUEST['parameters'])) {
+        && is_array($_REQUEST['parameters'])
+    ) {
         $parameters = $_REQUEST['parameters'];
         foreach ($parameters as $parameter => $replacement) {
             $quoted = preg_quote($parameter, '/');
@@ -199,7 +204,6 @@ if ($_POST == array() && $_GET == array()) {
     $_SESSION['Import_message']['message'] = $message->getDisplay();
     $_SESSION['Import_message']['go_back_url'] = $GLOBALS['goto'];
 
-    $response = PMA\libraries\Response::getInstance();
     $response->setRequestStatus(false);
     $response->addJSON('message', $message);
 
@@ -208,7 +212,6 @@ if ($_POST == array() && $_GET == array()) {
 
 // Add console message id to response output
 if (isset($_POST['console_message_id'])) {
-    $response = PMA\libraries\Response::getInstance();
     $response->addJSON('console_message_id', $_POST['console_message_id']);
 }
 
@@ -250,7 +253,7 @@ $format = PMA_securePath($format);
 
 // Create error and goto url
 if ($import_type == 'table') {
-    $err_url = 'tbl_import.php' . PMA_URL_getCommon(
+    $err_url = 'tbl_import.php' . URL::getCommon(
         array(
             'db' => $db, 'table' => $table
         )
@@ -258,29 +261,29 @@ if ($import_type == 'table') {
     $_SESSION['Import_message']['go_back_url'] = $err_url;
     $goto = 'tbl_import.php';
 } elseif ($import_type == 'database') {
-    $err_url = 'db_import.php' . PMA_URL_getCommon(array('db' => $db));
+    $err_url = 'db_import.php' . URL::getCommon(array('db' => $db));
     $_SESSION['Import_message']['go_back_url'] = $err_url;
     $goto = 'db_import.php';
 } elseif ($import_type == 'server') {
-    $err_url = 'server_import.php' . PMA_URL_getCommon();
+    $err_url = 'server_import.php' . URL::getCommon();
     $_SESSION['Import_message']['go_back_url'] = $err_url;
     $goto = 'server_import.php';
 } else {
     if (empty($goto) || !preg_match('@^(server|db|tbl)(_[a-z]*)*\.php$@i', $goto)) {
-        if (mb_strlen($table) && mb_strlen($db)) {
+        if (strlen($table) > 0 && strlen($db) > 0) {
             $goto = 'tbl_structure.php';
-        } elseif (mb_strlen($db)) {
+        } elseif (strlen($db) > 0) {
             $goto = 'db_structure.php';
         } else {
             $goto = 'server_sql.php';
         }
     }
-    if (mb_strlen($table) && mb_strlen($db)) {
-        $common = PMA_URL_getCommon(array('db' => $db, 'table' => $table));
-    } elseif (mb_strlen($db)) {
-        $common = PMA_URL_getCommon(array('db' => $db));
+    if (strlen($table) > 0 && strlen($db) > 0) {
+        $common = URL::getCommon(array('db' => $db, 'table' => $table));
+    } elseif (strlen($db) > 0) {
+        $common = URL::getCommon(array('db' => $db));
     } else {
-        $common = PMA_URL_getCommon();
+        $common = URL::getCommon();
     }
     $err_url  = $goto . $common
         . (preg_match('@^tbl_[a-z]*\.php$@', $goto)
@@ -295,7 +298,7 @@ if (basename($_SERVER['SCRIPT_NAME']) === 'import.php') {
 }
 
 
-if (mb_strlen($db)) {
+if (strlen($db) > 0) {
     $GLOBALS['dbi']->selectDb($db);
 }
 
@@ -327,23 +330,27 @@ $run_query = true;
 $charset_conversion = false;
 $reset_charset = false;
 $bookmark_created = false;
+$result = false;
+$msg = 'Sorry an unexpected error happened!';
 
 // Bookmark Support: get a query back from bookmark if required
 if (! empty($_REQUEST['id_bookmark'])) {
     $id_bookmark = (int)$_REQUEST['id_bookmark'];
-    include_once 'libraries/bookmark.lib.php';
     switch ($_REQUEST['action_bookmark']) {
     case 0: // bookmarked query that have to be run
-        $import_text = PMA_Bookmark_get(
+        $bookmark = Bookmark::get(
             $db,
             $id_bookmark,
             'id',
             isset($_REQUEST['action_bookmark_all'])
         );
+
         if (! empty($_REQUEST['bookmark_variable'])) {
-            $import_text = PMA_Bookmark_applyVariables(
-                $import_text
+            $import_text = $bookmark->applyVariables(
+                $_REQUEST['bookmark_variable']
             );
+        } else {
+            $import_text = $bookmark->getQuery();
         }
 
         // refresh navigation and main panels
@@ -365,10 +372,10 @@ if (! empty($_REQUEST['id_bookmark'])) {
         }
         break;
     case 1: // bookmarked query that have to be displayed
-        $import_text = PMA_Bookmark_get($db, $id_bookmark);
-        if ($GLOBALS['is_ajax_request'] == true) {
+        $bookmark = Bookmark::get($db, $id_bookmark);
+        $import_text = $bookmark->getQuery();
+        if ($response->isAjax()) {
             $message = PMA\libraries\Message::success(__('Showing bookmark'));
-            $response = PMA\libraries\Response::getInstance();
             $response->setRequestStatus($message->isSuccess());
             $response->addJSON('message', $message);
             $response->addJSON('sql_query', $import_text);
@@ -379,22 +386,24 @@ if (! empty($_REQUEST['id_bookmark'])) {
         }
         break;
     case 2: // bookmarked query that have to be deleted
-        $import_text = PMA_Bookmark_get($db, $id_bookmark);
-        PMA_Bookmark_delete($id_bookmark);
-        if ($GLOBALS['is_ajax_request'] == true) {
-            $message = PMA\libraries\Message::success(
-                __('The bookmark has been deleted.')
-            );
-            $response = PMA\libraries\Response::getInstance();
-            $response->setRequestStatus($message->isSuccess());
-            $response->addJSON('message', $message);
-            $response->addJSON('action_bookmark', $_REQUEST['action_bookmark']);
-            $response->addJSON('id_bookmark', $id_bookmark);
-            exit;
-        } else {
-            $run_query = false;
-            $error = true; // this is kind of hack to skip processing the query
+        $bookmark = Bookmark::get($db, $id_bookmark);
+        if (! empty($bookmark)) {
+            $bookmark->delete();
+            if ($response->isAjax()) {
+                $message = PMA\libraries\Message::success(
+                    __('The bookmark has been deleted.')
+                );
+                $response->setRequestStatus($message->isSuccess());
+                $response->addJSON('message', $message);
+                $response->addJSON('action_bookmark', $_REQUEST['action_bookmark']);
+                $response->addJSON('id_bookmark', $id_bookmark);
+                exit;
+            } else {
+                $run_query = false;
+                $error = true; // this is kind of hack to skip processing the query
+            }
         }
+
         break;
     }
 } // end bookmarks reading
@@ -459,132 +468,18 @@ if (! empty($local_import_file) && ! empty($cfg['UploadDir'])) {
 // Do we have file to import?
 
 if ($import_file != 'none' && ! $error) {
-    // work around open_basedir and other limitations
-    $open_basedir = @ini_get('open_basedir');
-
-    // If we are on a server with open_basedir, we must move the file
-    // before opening it.
-
-    if (! empty($open_basedir)) {
-        $tmp_subdir = ini_get('upload_tmp_dir');
-        if (empty($tmp_subdir)) {
-            $tmp_subdir = sys_get_temp_dir();
-        }
-        $tmp_subdir = rtrim($tmp_subdir, DIRECTORY_SEPARATOR);
-        if (@is_writable($tmp_subdir)) {
-            $import_file_new = $tmp_subdir . DIRECTORY_SEPARATOR
-                . basename($import_file) . uniqid();
-            if (move_uploaded_file($import_file, $import_file_new)) {
-                $import_file = $import_file_new;
-                $file_to_unlink = $import_file_new;
-            }
-
-            $size = filesize($import_file);
-        } else {
-
-            // If the php.ini is misconfigured (eg. there is no /tmp access defined
-            // with open_basedir), $tmp_subdir won't be writable and the user gets
-            // a 'File could not be read!' error (at PMA_detectCompression), which
-            // is not too meaningful. Show a meaningful error message to the user
-            // instead.
-
-            $message = PMA\libraries\Message::error(
-                __(
-                    'Uploaded file cannot be moved, because the server has ' .
-                    'open_basedir enabled without access to the %s directory ' .
-                    '(for temporary files).'
-                )
-            );
-            $message->addParam($tmp_subdir);
-            PMA_stopImport($message);
-        }
-    }
-
     /**
      *  Handle file compression
-     * @todo duplicate code exists in File.php
      */
-    $compression = PMA_detectCompression($import_file);
-    if ($compression === false) {
-        $message = PMA\libraries\Message::error(__('File could not be read!'));
-        PMA_stopImport($message); //Contains an 'exit'
+    $import_handle = new File($import_file);
+    $import_handle->checkUploadedFile();
+    if ($import_handle->isError()) {
+        PMA_stopImport($import_handle->getError());
     }
-
-    switch ($compression) {
-    case 'application/bzip2':
-        if ($cfg['BZipDump'] && @function_exists('bzopen')) {
-            $import_handle = @bzopen($import_file, 'r');
-        } else {
-            $message = PMA\libraries\Message::error(
-                __(
-                    'You attempted to load file with unsupported compression ' .
-                    '(%s). Either support for it is not implemented or disabled ' .
-                    'by your configuration.'
-                )
-            );
-            $message->addParam($compression);
-            PMA_stopImport($message);
-        }
-        break;
-    case 'application/gzip':
-        if ($cfg['GZipDump'] && @function_exists('gzopen')) {
-            $import_handle = @gzopen($import_file, 'r');
-        } else {
-            $message = PMA\libraries\Message::error(
-                __(
-                    'You attempted to load file with unsupported compression ' .
-                    '(%s). Either support for it is not implemented or disabled ' .
-                    'by your configuration.'
-                )
-            );
-            $message->addParam($compression);
-            PMA_stopImport($message);
-        }
-        break;
-    case 'application/zip':
-        if ($cfg['ZipDump'] && @function_exists('zip_open')) {
-            /**
-             * Load interface for zip extension.
-             */
-            include_once 'libraries/zip_extension.lib.php';
-            $zipResult = PMA_getZipContents($import_file);
-            if (! empty($zipResult['error'])) {
-                $message = PMA\libraries\Message::rawError($zipResult['error']);
-                PMA_stopImport($message);
-            } else {
-                $import_text = $zipResult['data'];
-            }
-        } else {
-            $message = PMA\libraries\Message::error(
-                __(
-                    'You attempted to load file with unsupported compression ' .
-                    '(%s). Either support for it is not implemented or disabled ' .
-                    'by your configuration.'
-                )
-            );
-            $message->addParam($compression);
-            PMA_stopImport($message);
-        }
-        break;
-    case 'none':
-        $import_handle = @fopen($import_file, 'r');
-        break;
-    default:
-        $message = PMA\libraries\Message::error(
-            __(
-                'You attempted to load file with unsupported compression (%s). ' .
-                'Either support for it is not implemented or disabled by your ' .
-                'configuration.'
-            )
-        );
-        $message->addParam($compression);
-        PMA_stopImport($message);
-        // the previous function exits
-    }
-    // use isset() because zip compression type does not use a handle
-    if (! $error && isset($import_handle) && $import_handle === false) {
-        $message = PMA\libraries\Message::error(__('File could not be read!'));
-        PMA_stopImport($message);
+    $import_handle->setDecompressContent(true);
+    $import_handle->open();
+    if ($import_handle->isError()) {
+        PMA_stopImport($import_handle->getError());
     }
 } elseif (! $error) {
     if (! isset($import_text) || empty($import_text)) {
@@ -603,7 +498,7 @@ if ($import_file != 'none' && ! $error) {
 //$_SESSION['Import_message'] = $message->getDisplay();
 
 // Convert the file's charset if necessary
-if ($GLOBALS['PMA_recoding_engine'] != PMA_CHARSET_NONE && isset($charset_of_file)) {
+if (Encoding::isSupported() && isset($charset_of_file)) {
     if ($charset_of_file != 'utf-8') {
         $charset_conversion = true;
     }
@@ -658,8 +553,8 @@ if (! $error) {
     }
 }
 
-if (! empty($import_handle)) {
-    fclose($import_handle);
+if (isset($import_handle)) {
+    $import_handle->close();
 }
 
 // Cleanup temporary file
@@ -703,14 +598,12 @@ if (! empty($id_bookmark) && $_REQUEST['action_bookmark'] == 2) {
         $message->addParam($executed_queries);
 
         if ($import_notice) {
-            $message->addString($import_notice);
+            $message->addHtml($import_notice);
         }
         if (! empty($local_import_file)) {
-            $message->addString('(' . htmlspecialchars($local_import_file) . ')');
+            $message->addText('(' . $local_import_file . ')');
         } else {
-            $message->addString(
-                '(' . htmlspecialchars($_FILES['import_file']['name']) . ')'
-            );
+            $message->addText('(' . $_FILES['import_file']['name'] . ')');
         }
     }
 }
@@ -729,11 +622,11 @@ if ($timeout_passed) {
             . ' please %sresubmit the same file%s and import will resume.'
         )
     );
-    $message->addParam('<a href="' . $importUrl . '">', false);
-    $message->addParam('</a>', false);
+    $message->addParamHtml('<a href="' . $importUrl . '">');
+    $message->addParamHtml('</a>');
 
     if ($offset == 0 || (isset($original_skip) && $original_skip == $offset)) {
-        $message->addString(
+        $message->addText(
             __(
                 'However on last run no data has been parsed,'
                 . ' this usually means phpMyAdmin won\'t be able to'
@@ -844,7 +737,7 @@ if ($go_sql) {
     // since only one bookmark has to be added for all the queries submitted through
     // the SQL tab
     if (! empty($_POST['bkm_label']) && ! empty($import_text)) {
-        $cfgBookmark = PMA_Bookmark_getParams();
+        $cfgBookmark = Bookmark::getParams();
         PMA_storeTheQueryAsBookmark(
             $db, $cfgBookmark['user'],
             $_REQUEST['sql_query'], $_POST['bkm_label'],
@@ -852,7 +745,6 @@ if ($go_sql) {
         );
     }
 
-    $response = PMA\libraries\Response::getInstance();
     $response->addJSON('ajax_reload', $ajax_reload);
     $response->addHTML($html_output);
     exit();
@@ -860,7 +752,7 @@ if ($go_sql) {
 } else if ($result) {
     // Save a Bookmark with more than one queries (if Bookmark label given).
     if (! empty($_POST['bkm_label']) && ! empty($import_text)) {
-        $cfgBookmark = PMA_Bookmark_getParams();
+        $cfgBookmark = Bookmark::getParams();
         PMA_storeTheQueryAsBookmark(
             $db, $cfgBookmark['user'],
             $_REQUEST['sql_query'], $_POST['bkm_label'],
@@ -868,7 +760,6 @@ if ($go_sql) {
         );
     }
 
-    $response = PMA\libraries\Response::getInstance();
     $response->setRequestStatus(true);
     $response->addJSON('message', PMA\libraries\Message::success($msg));
     $response->addJSON(
@@ -876,7 +767,6 @@ if ($go_sql) {
         PMA\libraries\Util::getMessage($msg, $sql_query, 'success')
     );
 } else if ($result == false) {
-    $response = PMA\libraries\Response::getInstance();
     $response->setRequestStatus(false);
     $response->addJSON('message', PMA\libraries\Message::error($msg));
 } else {
