@@ -126,7 +126,7 @@ function loadTemplate(id)
     $.post('tbl_export.php', params, function (response) {
         if (response.success === true) {
             var $form = $('form[name="dump"]');
-            var options = $.parseJSON(response.data);
+            var options = JSON.parse(response.data);
             $.each(options, function (key, value) {
                 var $element = $form.find('[name="' + key + '"]');
                 if ($element.length) {
@@ -305,29 +305,29 @@ AJAX.registerOnload('export.js', function () {
         } else {
             // enable the SQL comment options
             if (comments_are_present) {
-                $("#checkbox_sql_dates").removeProp('disabled').parent().fadeTo('fast', 1);
+                $("#checkbox_sql_dates").prop('disabled', false).parent().fadeTo('fast', 1);
             }
-            $("#checkbox_sql_relation").removeProp('disabled').parent().fadeTo('fast', 1);
-            $("#checkbox_sql_mime").removeProp('disabled').parent().fadeTo('fast', 1);
+            $("#checkbox_sql_relation").prop('disabled', false).parent().fadeTo('fast', 1);
+            $("#checkbox_sql_mime").prop('disabled', false).parent().fadeTo('fast', 1);
         }
 
         if (show == 'structure') {
             $('#checkbox_sql_auto_increment').prop('disabled', true).parent().fadeTo('fast', 0.4);
         } else {
-            $("#checkbox_sql_auto_increment").removeProp('disabled').parent().fadeTo('fast', 1);
+            $("#checkbox_sql_auto_increment").prop('disabled', false).parent().fadeTo('fast', 1);
         }
     });
 
     // For separate-file exports only ZIP compression is allowed
     $('input[type="checkbox"][name="as_separate_files"]').change(function(){
-        if (! $(this).attr('checked')) {
+        if ($(this).is(':checked')) {
             $('#compression').val('zip');
         }
     });
 
     $('#compression').change(function(){
         if ($('option:selected').val() !== 'zip') {
-            $('input[type="checkbox"][name="as_separate_files"]').attr('checked', false);
+            $('input[type="checkbox"][name="as_separate_files"]').prop('checked', false);
         }
     });
 
@@ -349,7 +349,7 @@ function setup_table_structure_or_data() {
     } else {
         $('input[name="structure_or_data_forced"]').val(0);
         $('.export_structure input[type="checkbox"], .export_data input[type="checkbox"]')
-            .removeProp('disabled');
+            .prop('disabled', false);
         $('.export_structure, .export_data').fadeTo('fast', 1);
 
         var structure_or_data = $('input[name="' + formElemName + '_default"]').val();
@@ -442,10 +442,10 @@ function toggle_sql_include_comments()
         } else {
             // If structure is not being exported, the comment options for structure should not be enabled
             if ($("#radio_sql_structure_or_data_data").prop("checked")) {
-                $("#text_sql_header_comment").removeProp('disabled').parent("li").fadeTo('fast', 1);
+                $("#text_sql_header_comment").prop('disabled', false).parent("li").fadeTo('fast', 1);
             } else {
                 $ulIncludeComments.find("> li").fadeTo('fast', 1);
-                $ulIncludeComments.find("> li > input").removeProp('disabled');
+                $ulIncludeComments.find("> li > input").prop('disabled', false);
             }
         }
     });
@@ -522,10 +522,13 @@ function check_table_selected(row) {
 
     if (data && structure) {
         table_select.prop({checked: true, indeterminate: false});
+        $row.addClass('marked');
     } else if (data || structure) {
         table_select.prop({checked: true, indeterminate: true});
+        $row.removeClass('marked');
     } else {
         table_select.prop({checked: false, indeterminate: false});
+        $row.removeClass('marked');
     }
 }
 
@@ -535,8 +538,20 @@ function toggle_table_select(row) {
 
     if (table_selected) {
         $row.find('input[type="checkbox"]:not(:disabled)').prop('checked', true);
+        $row.addClass('marked');
     } else {
         $row.find('input[type="checkbox"]:not(:disabled)').prop('checked', false);
+        $row.removeClass('marked');
+    }
+}
+
+function handleAddProcCheckbox() {
+    if ($('#table_structure_all').is(':checked') === true
+        && $('#table_data_all').is(':checked') === true
+    ) {
+        $('#checkbox_sql_procedure_function').prop('checked', true);
+    } else {
+        $('#checkbox_sql_procedure_function').prop('checked', false);
     }
 }
 
@@ -579,26 +594,31 @@ AJAX.registerOnload('export.js', function () {
     $('input[name="table_select[]"]').on('change', function() {
         toggle_table_select($(this).closest('tr'));
         check_table_select_all();
+        handleAddProcCheckbox();
     });
 
     $('input[name="table_structure[]"]').on('change', function() {
         check_table_selected($(this).closest('tr'));
         check_table_select_all();
+        handleAddProcCheckbox();
     });
 
     $('input[name="table_data[]"]').on('change', function() {
         check_table_selected($(this).closest('tr'));
         check_table_select_all();
+        handleAddProcCheckbox();
     });
 
     $('#table_structure_all').on('change', function() {
         toggle_table_select_all_str();
         check_selected_tables();
+        handleAddProcCheckbox();
     });
 
     $('#table_data_all').on('change', function() {
         toggle_table_select_all_data();
         check_selected_tables();
+        handleAddProcCheckbox();
     });
 
     if ($("input[name='export_type']").val() == 'database') {
@@ -805,6 +825,8 @@ AJAX.registerOnload('export.js', function () {
     toggle_quick_or_custom();
     toggle_structure_data_opts();
     toggle_sql_include_comments();
+    check_table_select_all();
+    handleAddProcCheckbox();
 
     /**
      * Initially disables the "Dump some row(s)" sub-options
