@@ -156,7 +156,7 @@ function drawChart() {
 
     var columnNames = [];
     $('select[name="chartXAxis"] option').each(function () {
-        columnNames.push($(this).text());
+        columnNames.push(escapeHtml($(this).text()));
     });
     try {
         currentChart = PMA_queryChart(chart_data, columnNames, currentSettings);
@@ -366,7 +366,7 @@ AJAX.registerOnload('tbl_chart.js', function () {
             if (typeof data !== 'undefined' &&
                     data.success === true &&
                     typeof data.chartData !== 'undefined') {
-                chart_data = jQuery.parseJSON(data.chartData);
+                chart_data = JSON.parse(data.chartData);
                 drawChart();
                 PMA_ajaxRemoveMessage($msgbox);
             } else {
