@@ -9,8 +9,9 @@ namespace PMA\libraries;
 
 use PMA\libraries\dbi\DBIExtension;
 use PMA\libraries\LanguageManager;
+use PMA\libraries\URL;
+use PMA\libraries\Logging;
 
-require_once './libraries/logging.lib.php';
 require_once './libraries/util.lib.php';
 
 /**
@@ -37,6 +38,21 @@ class DatabaseInterface
      */
     const GETVAR_GLOBAL = 2;
 
+    /**
+     * User connection.
+     */
+    const CONNECT_USER = 0x100;
+    /**
+     * Control user connection.
+     */
+    const CONNECT_CONTROL = 0x101;
+    /**
+     * Auxiliary connection.
+     *
+     * Used for example for replication setup.
+     */
+    const CONNECT_AUXILIARY = 0x102;
+
     /**
      * @var DBIExtension
      */
@@ -47,6 +63,11 @@ class DatabaseInterface
      */
     private $_table_cache;
 
+    /**
+     * @var array Current user and host cache
+     */
+    private $_current_user;
+
     /**
      * @var null|string lower_case_table_names value cache
      */
@@ -61,6 +82,7 @@ class DatabaseInterface
     {
         $this->_extension = $ext;
         $this->_table_cache = array();
+        $this->_current_user = array();
     }
 
     /**
@@ -232,12 +254,13 @@ class DatabaseInterface
     public function tryQuery($query, $link = null, $options = 0,
         $cache_affected_rows = true
     ) {
+        $debug = $GLOBALS['cfg']['DBG']['sql'];
         $link = $this->getLink($link);
         if ($link === false) {
             return false;
         }
 
-        if ($GLOBALS['cfg']['DBG']['sql']) {
+        if ($debug) {
             $time = microtime(true);
         }
 
@@ -247,12 +270,21 @@ class DatabaseInterface
             $GLOBALS['cached_affected_rows'] = $this->affectedRows($link, false);
         }
 
-        if ($GLOBALS['cfg']['DBG']['sql']) {
+        if ($debug) {
             $time = microtime(true) - $time;
             $this->_dbgQuery($query, $link, $result, $time);
+            if ($GLOBALS['cfg']['DBG']['sqllog']) {
+                openlog('phpMyAdmin', LOG_NDELAY | LOG_PID, LOG_USER);
+                syslog(
+                    LOG_INFO,
+                    'SQL[' . basename($_SERVER['SCRIPT_NAME']) . ']: '
+                    . sprintf('%0.3f', $time) . ' > ' . $query
+                );
+                closelog();
+            }
         }
 
-        if ((!empty($result)) && (Tracker::isActive())) {
+        if ($result !== false && Tracker::isActive()) {
             Tracker::handleQuery($query);
         }
 
@@ -287,21 +319,25 @@ class DatabaseInterface
      */
     public function getTables($database, $link = null)
     {
-        return $this->fetchResult(
+        $tables = $this->fetchResult(
             'SHOW TABLES FROM ' . Util::backquote($database) . ';',
             null,
             0,
             $link,
             self::QUERY_STORE
         );
+        if ($GLOBALS['cfg']['NaturalOrder']) {
+            uksort($tables, 'strnatcasecmp');
+        }
+        return $tables;
     }
 
     /**
      * returns a segment of the SQL WHERE clause regarding table name and type
      *
-     * @param string  $table        table
-     * @param boolean $tbl_is_group $table is a table group
-     * @param string  $table_type   whether table or view
+     * @param array|string $table        table(s)
+     * @param boolean      $tbl_is_group $table is a table group
+     * @param string       $table_type   whether table or view
      *
      * @return string a segment of the WHERE clause
      */
@@ -309,7 +345,18 @@ class DatabaseInterface
     {
         // get table information from information_schema
         if ($table) {
-            if (true === $tbl_is_group) {
+            if (is_array($table)) {
+                $sql_where_table = 'AND t.`TABLE_NAME` '
+                    . Util::getCollateForIS() . ' IN (\''
+                    . implode(
+                        '\', \'',
+                        array_map(
+                            array($this, 'escapeString'),
+                            $table
+                        )
+                    )
+                    . '\')';
+            } elseif (true === $tbl_is_group) {
                 $sql_where_table = 'AND t.`TABLE_NAME` LIKE \''
                     . Util::escapeMysqlWildcards(
                         $GLOBALS['dbi']->escapeString($table)
@@ -390,7 +437,7 @@ class DatabaseInterface
      * </code>
      *
      * @param string          $database     database
-     * @param string          $table        table name
+     * @param string|array    $table        table name(s)
      * @param boolean         $tbl_is_group $table is a table group
      * @param mixed           $link         mysql link
      * @param integer         $limit_offset zero-based offset for the count
@@ -493,11 +540,23 @@ class DatabaseInterface
                         . ' WHERE';
                     $needAnd = false;
                     if ($table || (true === $tbl_is_group)) {
-                        $sql .= " `Name` LIKE '"
-                            . Util::escapeMysqlWildcards(
-                                $this->escapeString($table, $link)
-                            )
-                            . "%'";
+                        if (is_array($table)) {
+                            $sql .= ' `Name` IN (\''
+                                . implode(
+                                    '\', \'',
+                                    array_map(
+                                        array($this, 'escapeString'),
+                                        $table,
+                                        $link
+                                    )
+                                ) . '\')';
+                        } else {
+                            $sql .= " `Name` LIKE '"
+                                . Util::escapeMysqlWildcards(
+                                    $this->escapeString($table, $link)
+                                )
+                                . "%'";
+                        }
                         $needAnd = true;
                     }
                     if (! empty($table_type)) {
@@ -515,38 +574,7 @@ class DatabaseInterface
                         . Util::backquote($each_database);
                 }
 
-                $useStatusCache = false;
-
-                if (extension_loaded('apc')
-                    && isset($GLOBALS['cfg']['Server']['StatusCacheDatabases'])
-                    && ! empty($GLOBALS['cfg']['Server']['StatusCacheLifetime'])
-                ) {
-                    $statusCacheDatabases
-                        = (array) $GLOBALS['cfg']['Server']['StatusCacheDatabases'];
-                    if (in_array($each_database, $statusCacheDatabases)) {
-                        $useStatusCache = true;
-                    }
-                }
-
-                $each_tables = null;
-
-                if ($useStatusCache) {
-                    $cacheKey = 'phpMyAdmin_tableStatus_'
-                        . sha1($GLOBALS['cfg']['Server']['host'] . '_' . $sql);
-
-                    $each_tables = apc_fetch($cacheKey);
-                }
-
-                if (! $each_tables) {
-                    $each_tables = $this->fetchResult($sql, 'Name', null, $link);
-                }
-
-                if ($useStatusCache) {
-                    apc_store(
-                        $cacheKey, $each_tables,
-                        $GLOBALS['cfg']['Server']['StatusCacheLifetime']
-                    );
-                }
+                $each_tables = $this->fetchResult($sql, 'Name', null, $link);
 
                 // Sort naturally if the config allows it and we're sorting
                 // the Name column.
@@ -608,11 +636,7 @@ class DatabaseInterface
                             =& $each_tables[$table_name]['Type'];
                     }
 
-                    // MySQL forward compatibility
-                    // so pma could use this array as if every server
-                    // is of version >5.0
-                    // todo : remove and check usage in the rest of the code,
-                    // MySQL 5.0 is required by current PMA version
+                    // Compatibility with INFORMATION_SCHEMA output
                     $each_tables[$table_name]['TABLE_SCHEMA']
                         = $each_database;
                     $each_tables[$table_name]['TABLE_NAME']
@@ -696,93 +720,6 @@ class DatabaseInterface
         return $tables;
     }
 
-    /**
-     * Copies the table properties to the set of property names used by PMA.
-     *
-     * @param array  $tables   array of table properties
-     * @param string $database database name
-     *
-     * @return array array with added properties
-     */
-    public function copyTableProperties($tables, $database)
-    {
-        foreach ($tables as $table_name => $each_table) {
-            if (! isset($tables[$table_name]['Type'])
-                && isset($tables[$table_name]['Engine'])
-            ) {
-                // pma BC, same parts of PMA still uses 'Type'
-                $tables[$table_name]['Type']
-                    =& $tables[$table_name]['Engine'];
-            } elseif (! isset($tables[$table_name]['Engine'])
-                && isset($tables[$table_name]['Type'])
-            ) {
-                // old MySQL reports Type, newer MySQL reports Engine
-                $tables[$table_name]['Engine']
-                    =& $tables[$table_name]['Type'];
-            }
-
-            // MySQL forward compatibility
-            // so pma could use this array as if every server
-            // is of version >5.0
-            // todo : remove and check usage in the rest of the code,
-            // MySQL 5.0 is required by current PMA version
-            $tables[$table_name]['TABLE_SCHEMA']
-                = $database;
-            $tables[$table_name]['TABLE_NAME']
-                =& $tables[$table_name]['Name'];
-            $tables[$table_name]['ENGINE']
-                =& $tables[$table_name]['Engine'];
-            $tables[$table_name]['VERSION']
-                =& $tables[$table_name]['Version'];
-            $tables[$table_name]['ROW_FORMAT']
-                =& $tables[$table_name]['Row_format'];
-            $tables[$table_name]['TABLE_ROWS']
-                =& $tables[$table_name]['Rows'];
-            $tables[$table_name]['AVG_ROW_LENGTH']
-                =& $tables[$table_name]['Avg_row_length'];
-            $tables[$table_name]['DATA_LENGTH']
-                =& $tables[$table_name]['Data_length'];
-            $tables[$table_name]['MAX_DATA_LENGTH']
-                =& $tables[$table_name]['Max_data_length'];
-            $tables[$table_name]['INDEX_LENGTH']
-                =& $tables[$table_name]['Index_length'];
-            $tables[$table_name]['DATA_FREE']
-                =& $tables[$table_name]['Data_free'];
-            $tables[$table_name]['AUTO_INCREMENT']
-                =& $tables[$table_name]['Auto_increment'];
-            $tables[$table_name]['CREATE_TIME']
-                =& $tables[$table_name]['Create_time'];
-            $tables[$table_name]['UPDATE_TIME']
-                =& $tables[$table_name]['Update_time'];
-            $tables[$table_name]['CHECK_TIME']
-                =& $tables[$table_name]['Check_time'];
-            $tables[$table_name]['TABLE_COLLATION']
-                =& $tables[$table_name]['Collation'];
-            $tables[$table_name]['CHECKSUM']
-                =& $tables[$table_name]['Checksum'];
-            $tables[$table_name]['CREATE_OPTIONS']
-                =& $tables[$table_name]['Create_options'];
-            $tables[$table_name]['TABLE_COMMENT']
-                =& $tables[$table_name]['Comment'];
-
-            $commentUpper = mb_strtoupper(
-                $tables[$table_name]['Comment']
-            );
-            if ($commentUpper === 'VIEW'
-                && $tables[$table_name]['Engine'] == null
-            ) {
-                $tables[$table_name]['TABLE_TYPE'] = 'VIEW';
-            } else {
-                /**
-                 * @todo difference between 'TEMPORARY' and 'BASE TABLE'
-                 * but how to detect?
-                 */
-                $tables[$table_name]['TABLE_TYPE'] = 'BASE TABLE';
-            }
-        }
-        return $tables;
-    }
-
     /**
      * Get VIEWs in a particular database
      *
@@ -917,15 +854,11 @@ class DatabaseInterface
         } else {
             $databases = array();
             foreach ($GLOBALS['dblist']->databases as $database_name) {
-                // MySQL forward compatibility
-                // so pma could use this array as if every server is of version >5.0
-                // todo : remove and check the rest of the code for usage,
-                // MySQL 5.0 or higher is required for current PMA version
+                // Compatibility with INFORMATION_SCHEMA output
                 $databases[$database_name]['SCHEMA_NAME']      = $database_name;
 
-                include_once './libraries/mysql_charsets.inc.php';
                 $databases[$database_name]['DEFAULT_COLLATION_NAME']
-                    = PMA_getDbCollation($database_name);
+                    = $this->getDbCollation($database_name);
 
                 if (!$force_stats) {
                     continue;
@@ -1159,10 +1092,7 @@ class DatabaseInterface
             $ordinal_position = 1;
             foreach ($columns as $column_name => $each_column) {
 
-                // MySQL forward compatibility
-                // so pma could use this array as if every server is of version >5.0
-                // todo : remove and check the rest of the code for usage,
-                // MySQL 5.0 or higher is required for current PMA version
+                // Compatibility with INFORMATION_SCHEMA output
                 $columns[$column_name]['COLUMN_NAME']
                     =& $columns[$column_name]['Field'];
                 $columns[$column_name]['COLUMN_TYPE']
@@ -1400,7 +1330,7 @@ class DatabaseInterface
         if ($link === false) {
             return false;
         }
-        $current_value = $GLOBALS['dbi']->getVariable(
+        $current_value = $this->getVariable(
             $var, self::GETVAR_SESSION, $link
         );
         if ($current_value == $value) {
@@ -2117,7 +2047,7 @@ class DatabaseInterface
                  */
                 $error .= ' - ' . $error_message .
                     ' (<a href="server_engines.php' .
-                    PMA_URL_getCommon(
+                    URL::getCommon(
                         array('engine' => 'InnoDB', 'page' => 'Status')
                     ) . '">' . __('Details…') . '</a>)';
             }
@@ -2138,12 +2068,12 @@ class DatabaseInterface
         if (Util::cacheExists('mysql_cur_user')) {
             return Util::cacheGet('mysql_cur_user');
         }
-        $user = $GLOBALS['dbi']->fetchValue('SELECT CURRENT_USER();');
+        $user = $this->fetchValue('SELECT CURRENT_USER();');
         if ($user !== false) {
             Util::cacheSet('mysql_cur_user', $user);
-            return Util::cacheGet('mysql_cur_user');
+            return $user;
         }
-        return '';
+        return '@';
     }
 
     /**
@@ -2184,12 +2114,12 @@ class DatabaseInterface
             if ($type === 'super') {
                 $query = 'SELECT 1 FROM mysql.user LIMIT 1';
             } elseif ($type === 'create') {
-                list($user, $host) = $this->_getCurrentUserAndHost();
+                list($user, $host) = $this->getCurrentUserAndHost();
                 $query = "SELECT 1 FROM `INFORMATION_SCHEMA`.`USER_PRIVILEGES` "
                     . "WHERE `PRIVILEGE_TYPE` = 'CREATE USER' AND "
                     . "'''" . $user . "''@''" . $host . "''' LIKE `GRANTEE` LIMIT 1";
             } elseif ($type === 'grant') {
-                list($user, $host) = $this->_getCurrentUserAndHost();
+                list($user, $host) = $this->getCurrentUserAndHost();
                 $query = "SELECT 1 FROM ("
                     . "SELECT `GRANTEE`, `IS_GRANTABLE` FROM "
                     . "`INFORMATION_SCHEMA`.`COLUMN_PRIVILEGES` UNION "
@@ -2204,20 +2134,20 @@ class DatabaseInterface
             }
 
             $is = false;
-            $result = $GLOBALS['dbi']->tryQuery(
+            $result = $this->tryQuery(
                 $query,
                 $GLOBALS['userlink'],
                 self::QUERY_STORE
             );
             if ($result) {
-                $is = (bool) $GLOBALS['dbi']->numRows($result);
+                $is = (bool) $this->numRows($result);
             }
-            $GLOBALS['dbi']->freeResult($result);
+            $this->freeResult($result);
 
             Util::cacheSet('is_' . $type . 'user', $is);
         } else {
             $is = false;
-            $grants = $GLOBALS['dbi']->fetchResult(
+            $grants = $this->fetchResult(
                 "SHOW GRANTS FOR CURRENT_USER();",
                 null,
                 null,
@@ -2253,10 +2183,13 @@ class DatabaseInterface
      *
      * @return array array of username and hostname
      */
-    private function _getCurrentUserAndHost()
+    public function getCurrentUserAndHost()
     {
-        $user = $GLOBALS['dbi']->fetchValue("SELECT CURRENT_USER();");
-        return explode("@", $user);
+        if (count($this->_current_user) == 0) {
+            $user = $this->getCurrentUser();
+            $this->_current_user = explode("@", $user);
+        }
+        return $this->_current_user;
     }
 
     /**
@@ -2311,37 +2244,131 @@ class DatabaseInterface
             || $schema_name == 'sys';
     }
 
+    /**
+     * Return connection parameters for the database server
+     *
+     * @param integer $mode   Connection mode on of CONNECT_USER, CONNECT_CONTROL
+     *                        or CONNECT_AUXILIARY.
+     * @param array   $server Server information like host/port/socket/persistent
+     *
+     * @return array user, host and server settings array
+     */
+    public function getConnectionParams($mode, $server = null)
+    {
+        global $cfg;
+
+        $user = null;
+        $password = null;
+
+        if ($mode == DatabaseInterface::CONNECT_USER) {
+            $user = $cfg['Server']['user'];
+            $password = $cfg['Server']['password'];
+            $server = $cfg['Server'];
+        } elseif ($mode == DatabaseInterface::CONNECT_CONTROL) {
+            $user = $cfg['Server']['controluser'];
+            $password = $cfg['Server']['controlpass'];
+
+            $server = array();
+
+            if (! empty($cfg['Server']['controlhost'])) {
+                $server['host'] = $cfg['Server']['controlhost'];
+            } else {
+                $server['host'] = $cfg['Server']['host'];
+            }
+            // Share the settings if the host is same
+            if ($server['host'] == $cfg['Server']['host']) {
+                $shared = array(
+                    'port', 'socket', 'compress',
+                    'ssl', 'ssl_key', 'ssl_cert', 'ssl_ca',
+                    'ssl_ca_path',  'ssl_ciphers', 'ssl_verify',
+                );
+                foreach ($shared as $item) {
+                    if (isset($cfg['Server'][$item])) {
+                        $server[$item] = $cfg['Server'][$item];
+                    }
+                }
+            }
+            // Set configured port
+            if (! empty($cfg['Server']['controlport'])) {
+                $server['port'] = $cfg['Server']['controlport'];
+            }
+            // Set any configuration with control_ prefix
+            foreach ($cfg['Server'] as $key => $val) {
+                if (substr($key, 0, 8) === 'control_') {
+                    $server[substr($key, 8)] = $val;
+                }
+            }
+        } else {
+            if (is_null($server)) {
+                return array(null, null, null);
+            }
+            if (isset($server['user'])) {
+                $user = $server['user'];
+            }
+            if (isset($server['password'])) {
+                $password = $server['password'];
+            }
+        }
+
+        // Perform sanity checks on some variables
+        if (empty($server['port'])) {
+            $server['port'] = 0;
+        } else {
+            $server['port'] = intval($server['port']);
+        }
+        if (empty($server['socket'])) {
+            $server['socket'] = null;
+        }
+        if (empty($server['host'])) {
+            $server['host'] = 'localhost';
+        }
+        if (!isset($server['ssl'])) {
+            $server['ssl'] = false;
+        }
+        if (!isset($server['compress'])) {
+            $server['compress'] = false;
+        }
+
+        return array($user, $password, $server);
+    }
+
     /**
      * connects to the database server
      *
-     * @param string $user                 user name
-     * @param string $password             user password
-     * @param bool   $is_controluser       whether this is a control user connection
-     * @param array  $server               host/port/socket/persistent
-     * @param bool   $auxiliary_connection (when true, don't go back to login if
-     *                                     connection fails)
+     * @param integer $mode   Connection mode on of CONNECT_USER, CONNECT_CONTROL
+     *                        or CONNECT_AUXILIARY.
+     * @param array   $server Server information like host/port/socket/persistent
      *
      * @return mixed false on error or a connection object on success
      */
-    public function connect(
-        $user, $password, $is_controluser = false, $server = null,
-        $auxiliary_connection = false
-    ) {
+    public function connect($mode, $server = null)
+    {
+        list($user, $password, $server) = $this->getConnectionParams($mode, $server);
+
+        if (is_null($user) || is_null($password)) {
+            trigger_error(
+                __('Missing connection parameters!'),
+                E_USER_WARNING
+            );
+            return false;
+        }
+
         // Do not show location and backtrace for connection errors
         $GLOBALS['error_handler']->setHideLocation(true);
         $result = $this->_extension->connect(
-            $user, $password, $is_controluser, $server, $auxiliary_connection
+            $user, $password, $server
         );
         $GLOBALS['error_handler']->setHideLocation(false);
 
         if ($result) {
-            if (! $auxiliary_connection && ! $is_controluser) {
-                $GLOBALS['dbi']->postConnect($result);
+            /* Run post connect for user connections */
+            if ($mode == DatabaseInterface::CONNECT_USER) {
+                $this->postConnect($result);
             }
             return $result;
         }
 
-        if ($is_controluser) {
+        if ($mode == DatabaseInterface::CONNECT_CONTROL) {
             trigger_error(
                 __(
                     'Connection for controluser as defined in your '
@@ -2350,15 +2377,13 @@ class DatabaseInterface
                 E_USER_WARNING
             );
             return false;
-        }
-
-        // Do not go back to main login if connection failed
-        // (currently used only in unit testing)
-        if ($auxiliary_connection) {
+        } else if ($mode == DatabaseInterface::CONNECT_AUXILIARY) {
+            // Do not go back to main login if connection failed
+            // (currently used only in unit testing)
             return false;
         }
 
-        PMA_logUser($user, 'mysql-denied');
+        Logging::logUser($user, 'mysql-denied');
         $GLOBALS['auth_plugin']->authFails();
 
         return $result;
@@ -2579,7 +2604,7 @@ class DatabaseInterface
         // When no controluser is defined, using mysqli_insert_id($link)
         // does not always return the last insert id due to a mixup with
         // the tracking mechanism, but this works:
-        return $GLOBALS['dbi']->fetchValue('SELECT LAST_INSERT_ID();', 0, 0, $link);
+        return $this->fetchValue('SELECT LAST_INSERT_ID();', 0, 0, $link);
     }
 
     /**
@@ -2706,46 +2731,7 @@ class DatabaseInterface
         return $this->_extension->escapeString($link, $str);
     }
 
-    /**
-     * Gets server connection port
-     *
-     * @param array|null $server host/port/socket/persistent
-     *
-     * @return int
-     */
-    public function getServerPort($server = null)
-    {
-        if (is_null($server)) {
-            $server = &$GLOBALS['cfg']['Server'];
-        }
-
-        if (empty($server['port'])) {
-            return 0;
-        }
-        return intval($server['port']);
-    }
-
-    /**
-     * Gets server connection socket
-     *
-     * @param array|null $server host/port/socket/persistent
-     *
-     * @return null|string
-     */
-    public function getServerSocket($server = null)
-    {
-        if (is_null($server)) {
-            $server = &$GLOBALS['cfg']['Server'];
-        }
-
-        if (empty($server['socket'])) {
-            return null;
-        } else {
-            return $server['socket'];
-        }
-    }
-
-    /**
+    /*
      * Gets correct link object.
      *
      * @param object $link optional database link to use
@@ -2821,4 +2807,45 @@ class DatabaseInterface
     {
         return new Table($table_name, $db_name, $this);
     }
+
+    /**
+     * returns collation of given db
+     *
+     * @param string $db name of db
+     *
+     * @return string  collation of $db
+     */
+    public function getDbCollation($db)
+    {
+        if ($this->isSystemSchema($db)) {
+            // We don't have to check the collation of the virtual
+            // information_schema database: We know it!
+            return 'utf8_general_ci';
+        }
+
+        if (! $GLOBALS['cfg']['Server']['DisableIS']) {
+            // this is slow with thousands of databases
+            $sql = 'SELECT DEFAULT_COLLATION_NAME FROM information_schema.SCHEMATA'
+                . ' WHERE SCHEMA_NAME = \'' . $this->escapeString($db)
+                . '\' LIMIT 1';
+            return $this->fetchValue($sql);
+        } else {
+            $this->selectDb($db);
+            $return = $this->fetchValue('SELECT @@collation_database');
+            if ($db !== $GLOBALS['db']) {
+                $this->selectDb($GLOBALS['db']);
+            }
+            return $return;
+        }
+    }
+
+    /**
+     * returns default server collation from show variables
+     *
+     * @return string  $server_collation
+     */
+    function getServerCollation()
+    {
+        return $this->fetchValue('SELECT @@collation_server');
+    }
 }
