@@ -8,6 +8,7 @@
  * @package PhpMyAdmin
  */
 use PMA\libraries\Table;
+use PMA\libraries\URL;
 
 /**
  * Gets url params
@@ -326,7 +327,7 @@ function PMA_buildOrExecuteQueryForMulti(
 function PMA_getHtmlForCopyMultipleTables($action, $_url_params)
 {
     $html = '<form id="ajax_form" action="' . $action . '" method="post">';
-    $html .= PMA_URL_getHiddenInputs($_url_params);
+    $html .= URL::getHiddenInputs($_url_params);
     $html .= '<fieldset class = "input">';
     $databases_list = $GLOBALS['dblist']->databases;
     foreach ($databases_list as $key => $db_name)
@@ -371,7 +372,7 @@ function PMA_getHtmlForCopyMultipleTables($action, $_url_params)
 function PMA_getHtmlForReplacePrefixTable($action, $_url_params)
 {
     $html  = '<form id="ajax_form" action="' . $action . '" method="post">';
-    $html .= PMA_URL_getHiddenInputs($_url_params);
+    $html .= URL::getHiddenInputs($_url_params);
     $html .= '<fieldset class = "input">';
     $html .= '<table>';
     $html .= '<tr>';
@@ -405,7 +406,7 @@ function PMA_getHtmlForReplacePrefixTable($action, $_url_params)
 function PMA_getHtmlForAddPrefixTable($action, $_url_params)
 {
     $html  = '<form id="ajax_form" action="' . $action . '" method="post">';
-    $html .= PMA_URL_getHiddenInputs($_url_params);
+    $html .= URL::getHiddenInputs($_url_params);
     $html .= '<fieldset class = "input">';
     $html .= '<table>';
     $html .= '<tr>';
@@ -436,7 +437,7 @@ function PMA_getHtmlForAddPrefixTable($action, $_url_params)
 function PMA_getHtmlForOtherActions($what, $action, $_url_params, $full_query)
 {
     $html = '<form action="' . $action . '" method="post">';
-    $html .= PMA_URL_getHiddenInputs($_url_params);
+    $html .= URL::getHiddenInputs($_url_params);
     $html .= '<fieldset class="confirmation">';
     $html .= '<legend>';
     if ($what == 'drop_db') {
