@@ -6,12 +6,14 @@
  * @todo    add an option to use mm-module for session handler
  *
  * @package PhpMyAdmin
- * @see     https://www.php.net/session
+ * @see     https://secure.php.net/session
  */
 if (! defined('PHPMYADMIN')) {
     exit;
 }
 
+require_once 'libraries/session.lib.php';
+
 // verify if PHP supports session, die if it does not
 
 if (!@function_exists('session_name')) {
@@ -28,7 +30,7 @@ if (!@function_exists('session_name')) {
 
 // session cookie settings
 session_set_cookie_params(
-    0, $GLOBALS['PMA_Config']->getCookiePath(),
+    0, $GLOBALS['PMA_Config']->getRootPath(),
     '', $GLOBALS['PMA_Config']->isHttps(), true
 );
 
@@ -86,9 +88,9 @@ function PMA_sessionFailed($errors)
          * will not change in future.
          */
         $messages[] = preg_replace(
-            '/open(.*, O_RDWR)/',
+            '/open\(.*, O_RDWR\)/',
             'open(SESSION_FILE, O_RDWR)',
-            $error->getMessage()
+            htmlspecialchars($error->getMessage())
         );
     }
 
@@ -137,11 +139,7 @@ unset($orig_error_count, $session_result);
  * (we use "space PMA_token space" to prevent overwriting)
  */
 if (! isset($_SESSION[' PMA_token '])) {
-    if (! function_exists('openssl_random_pseudo_bytes')) {
-        $_SESSION[' PMA_token '] = bin2hex(phpseclib\Crypt\Random::string(16));
-    } else {
-        $_SESSION[' PMA_token '] = bin2hex(openssl_random_pseudo_bytes(16));
-    }
+    PMA_generateToken();
 
     /**
      * Check for disk space on session storage by trying to write it.
@@ -157,13 +155,3 @@ if (! isset($_SESSION[' PMA_token '])) {
     }
     session_start();
 }
-/**
- * Check if token is properly generated (both above functions can return false).
- */
-if (empty($_SESSION[' PMA_token '])) {
-    PMA_fatalError(
-        'Failed to generate random CSRF token!'
-    );
-}
-
-require_once 'libraries/session.lib.php';
