@@ -9,6 +9,8 @@ use PMA\libraries\DisplayResults;
 use PMA\libraries\Message;
 use PMA\libraries\Table;
 use PMA\libraries\Response;
+use PMA\libraries\URL;
+use PMA\libraries\Bookmark;
 
 /**
  * Parses and analyzes the given SQL query.
@@ -61,19 +63,19 @@ function PMA_handleSortOrder(
         );
 
         // Create the new query.
-        $full_sql_query = SqlParser\Utils\Query::replaceClause(
+        $full_sql_query = PhpMyAdmin\SqlParser\Utils\Query::replaceClause(
             $analyzed_sql_results['statement'],
             $analyzed_sql_results['parser']->list,
             'ORDER BY ' . $sortCol
         );
 
         // TODO: Avoid reparsing the query.
-        $analyzed_sql_results = SqlParser\Utils\Query::getAll($full_sql_query);
+        $analyzed_sql_results = PhpMyAdmin\SqlParser\Utils\Query::getAll($full_sql_query);
     } else {
         // Store the remembered table into session.
         $pmatable->setUiProp(
             Table::PROP_SORTED_COLUMN,
-            SqlParser\Utils\Query::getClause(
+            PhpMyAdmin\SqlParser\Utils\Query::getClause(
                 $analyzed_sql_results['statement'],
                 $analyzed_sql_results['parser']->list,
                 'ORDER BY'
@@ -91,7 +93,7 @@ function PMA_handleSortOrder(
  */
 function PMA_getSqlWithLimitClause(&$analyzed_sql_results)
 {
-    return SqlParser\Utils\Query::replaceClause(
+    return PhpMyAdmin\SqlParser\Utils\Query::replaceClause(
         $analyzed_sql_results['statement'],
         $analyzed_sql_results['parser']->list,
         'LIMIT ' . $_SESSION['tmpval']['pos'] . ', '
@@ -188,7 +190,7 @@ function PMA_getHtmlForRelationalColumnDropdown($db, $table, $column, $curr_valu
             . htmlspecialchars($_REQUEST['curr_value'])
             . '</span>'
             . '<a href="browse_foreigners.php'
-            . PMA_URL_getCommon($_url_params) . '"'
+            . URL::getCommon($_url_params) . '"'
             . 'class="ajax browse_foreign" ' . '>'
             . __('Browse foreign values')
             . '</a>';
@@ -222,7 +224,7 @@ function PMA_getHtmlForProfilingChart($url_query, $db, $profiling_results)
         $pma_token = $_SESSION[' PMA_token '];
         $url_query = isset($url_query)
             ? $url_query
-            : PMA_URL_getCommon(array('db' => $db));
+            : URL::getCommon(array('db' => $db));
 
         $profiling_table = '';
         $profiling_table .= '<fieldset><legend>' . __('Profiling')
@@ -536,7 +538,7 @@ function PMA_getHtmlForBookmark($displayParts, $cfgBookmark, $sql_query, $db,
         && ! empty($sql_query)
     ) {
         $goto = 'sql.php'
-            . PMA_URL_getCommon(
+            . URL::getCommon(
                 array(
                     'db' => $db,
                     'table' => $table,
@@ -549,7 +551,7 @@ function PMA_getHtmlForBookmark($displayParts, $cfgBookmark, $sql_query, $db,
             . ' onsubmit="return ! emptyCheckTheField(this,'
             . '\'bkm_fields[bkm_label]\');"'
             . ' class="bookmarkQueryForm print_ignore">';
-        $html .= PMA_URL_getHiddenInputs();
+        $html .= URL::getHiddenInputs();
         $html .= '<input type="hidden" name="db"'
             . ' value="' . htmlspecialchars($db) . '" />';
         $html .= '<input type="hidden" name="goto" value="' . $goto . '" />';
@@ -625,7 +627,13 @@ function PMA_isRememberSortingOrder($analyzed_sql_results)
  */
 function PMA_isAppendLimitClause($analyzed_sql_results)
 {
-    return ($_SESSION['tmpval']['max_rows'] != 'all')
+    // Assigning LIMIT clause to an syntactically-wrong query
+    // is not needed. Also we would want to show the true query
+    // and the true error message to the query executor
+
+    return (isset($analyzed_sql_results['parser'])
+        && count($analyzed_sql_results['parser']->errors) === 0)
+        && ($_SESSION['tmpval']['max_rows'] != 'all')
         && ! ($analyzed_sql_results['is_export']
         || $analyzed_sql_results['is_analyse'])
         && ($analyzed_sql_results['select_from']
@@ -649,13 +657,14 @@ function PMA_isJustBrowsing($analyzed_sql_results, $find_real_end)
         && empty($analyzed_sql_results['union'])
         && empty($analyzed_sql_results['distinct'])
         && $analyzed_sql_results['select_from']
-        && (count($analyzed_sql_results['select_tables']) <= 1)
+        && (count($analyzed_sql_results['select_tables']) === 1)
         && (empty($analyzed_sql_results['statement']->where)
             || (count($analyzed_sql_results['statement']->where) == 1
                 && $analyzed_sql_results['statement']->where[0]->expr ==='1'))
         && empty($analyzed_sql_results['group'])
         && ! isset($find_real_end)
         && ! $analyzed_sql_results['is_subquery']
+        && ! $analyzed_sql_results['join']
         && empty($analyzed_sql_results['having']);
 }
 
@@ -687,8 +696,7 @@ function PMA_isDeleteTransformationInfo($analyzed_sql_results)
 function PMA_hasNoRightsToDropDatabase($analyzed_sql_results,
     $allowUserDropDatabase, $is_superuser
 ) {
-    return ! defined('PMA_CHK_DROP')
-        && ! $allowUserDropDatabase
+    return ! $allowUserDropDatabase
         && isset($analyzed_sql_results['drop_database'])
         && $analyzed_sql_results['drop_database']
         && ! $is_superuser;
@@ -721,7 +729,7 @@ function PMA_setColumnProperty($pmatable, $request_index)
         $_REQUEST['table_create_time']
     );
     if (gettype($retval) != 'boolean') {
-        $response = PMA\libraries\Response::getInstance();
+        $response = Response::getInstance();
         $response->setRequestStatus(false);
         $response->addJSON('message', $retval->getString());
         exit;
@@ -753,7 +761,7 @@ function PMA_setColumnOrderOrVisibility($table, $db)
         $retval = PMA_setColumnProperty($pmatable, 'col_visib');
     }
 
-    $response = PMA\libraries\Response::getInstance();
+    $response = Response::getInstance();
     $response->setRequestStatus($retval == true);
     exit;
 }
@@ -767,12 +775,13 @@ function PMA_setColumnOrderOrVisibility($table, $db)
  */
 function PMA_addBookmark($goto)
 {
-    $result = PMA_Bookmark_save(
+    $bookmark = Bookmark::createBookmark(
         $_POST['bkm_fields'],
         (isset($_POST['bkm_all_users'])
             && $_POST['bkm_all_users'] == 'true' ? true : false
         )
     );
+    $result = $bookmark->save();
     $response = Response::getInstance();
     if ($response->isAjax()) {
         if ($result) {
@@ -835,7 +844,7 @@ function PMA_getRelationalValues($db, $table)
     $dropdown = PMA_getHtmlForRelationalColumnDropdown(
         $db, $table, $column, $curr_value
     );
-    $response = PMA\libraries\Response::getInstance();
+    $response = Response::getInstance();
     $response->addJSON('dropdown', $dropdown);
     exit;
 }
@@ -853,7 +862,7 @@ function PMA_getEnumOrSetValues($db, $table, $columnType)
 {
     $column = $_REQUEST['column'];
     $curr_value = $_REQUEST['curr_value'];
-    $response = PMA\libraries\Response::getInstance();
+    $response = Response::getInstance();
     if ($columnType == "enum") {
         $dropdown = PMA_getHtmlForEnumColumnDropdown(
             $db, $table, $column, $curr_value
@@ -878,24 +887,23 @@ function PMA_getEnumOrSetValues($db, $table, $columnType)
  */
 function PMA_getDefaultSqlQueryForBrowse($db, $table)
 {
-    include_once 'libraries/bookmark.lib.php';
-    $book_sql_query = PMA_Bookmark_get(
+    $bookmark = Bookmark::get(
         $db,
-        '\'' . PMA\libraries\Util::sqlAddSlashes($table) . '\'',
+        $table,
         'label',
         false,
         true
     );
 
-    if (! empty($book_sql_query)) {
+    if (! empty($bookmark) && ! empty($bookmark->getQuery())) {
         $GLOBALS['using_bookmark_message'] = Message::notice(
             __('Using bookmark "%s" as default browse query.')
         );
         $GLOBALS['using_bookmark_message']->addParam($table);
-        $GLOBALS['using_bookmark_message']->addMessage(
+        $GLOBALS['using_bookmark_message']->addHtml(
             PMA\libraries\Util::showDocu('faq', 'faq6-22')
         );
-        $sql_query = $book_sql_query;
+        $sql_query = $bookmark->getQuery();
     } else {
 
         $defaultOrderByClause = '';
@@ -931,7 +939,6 @@ function PMA_getDefaultSqlQueryForBrowse($db, $table)
             . $defaultOrderByClause;
 
     }
-    unset($book_sql_query);
 
     return $sql_query;
 }
@@ -949,7 +956,7 @@ function PMA_handleQueryExecuteError($is_gotofile, $error, $full_sql_query)
 {
     if ($is_gotofile) {
         $message = PMA\libraries\Message::rawError($error);
-        $response = PMA\libraries\Response::getInstance();
+        $response = Response::getInstance();
         $response->setRequestStatus(false);
         $response->addJSON('message', $message);
     } else {
@@ -972,7 +979,6 @@ function PMA_handleQueryExecuteError($is_gotofile, $error, $full_sql_query)
 function PMA_storeTheQueryAsBookmark($db, $bkm_user, $sql_query_for_bookmark,
     $bkm_label, $bkm_replace
 ) {
-    include_once 'libraries/bookmark.lib.php';
     $bfields = array(
                  'bkm_database' => $db,
                  'bkm_user'  => $bkm_user,
@@ -982,16 +988,16 @@ function PMA_storeTheQueryAsBookmark($db, $bkm_user, $sql_query_for_bookmark,
 
     // Should we replace bookmark?
     if (isset($bkm_replace)) {
-        $bookmarks = PMA_Bookmark_getList($db);
-        foreach ($bookmarks as $key => $val) {
-            if ($val['label'] == $bkm_label) {
-                PMA_Bookmark_delete($key);
+        $bookmarks = Bookmark::getList($db);
+        foreach ($bookmarks as $bookmark) {
+            if ($bookmark->getLabel() == $bkm_label) {
+                $bookmark->delete();
             }
         }
     }
 
-    PMA_Bookmark_save($bfields, isset($_POST['bkm_all_users']));
-
+    $bookmark = Bookmark::createBookmark($bfields, isset($_POST['bkm_all_users']));
+    $bookmark->save();
 }
 
 /**
@@ -1049,7 +1055,7 @@ function PMA_getNumberOfRowsAffectedOrChanged($is_affected, $result)
  */
 function PMA_hasCurrentDbChanged($db)
 {
-    if (mb_strlen($db)) {
+    if (strlen($db) > 0) {
         $current_db = $GLOBALS['dbi']->fetchValue('SELECT DATABASE()');
         // $current_db is false, except when a USE statement was sent
         return ($current_db != false) && ($db !== $current_db);
@@ -1072,9 +1078,9 @@ function PMA_cleanupRelations($db, $table, $column, $purge)
 {
     include_once 'libraries/relation_cleanup.lib.php';
 
-    if (! empty($purge) && mb_strlen($db)) {
-        if (mb_strlen($table)) {
-            if (isset($column) && mb_strlen($column)) {
+    if (! empty($purge) && strlen($db) > 0) {
+        if (strlen($table) > 0) {
+            if (isset($column) && strlen($column) > 0) {
                 PMA_relationsCleanupColumn($db, $table, $column);
             } else {
                 PMA_relationsCleanupTable($db, $table);
@@ -1117,7 +1123,7 @@ function PMA_countQueryResults(
     ) {
         //    c o u n t    q u e r y
 
-        // If we are "just browsing", there is only one table,
+        // If we are "just browsing", there is only one table (and no join),
         // and no WHERE clause (or just 'WHERE 1 '),
         // we do a quick count (which uses MaxExactCount) because
         // SQL_CALC_FOUND_ROWS is not quick on large InnoDB tables
@@ -1150,7 +1156,7 @@ function PMA_countQueryResults(
             // For UNION statements, only a SQL_CALC_FOUND_ROWS is required
             // after the first SELECT.
 
-            $count_query = SqlParser\Utils\Query::replaceClause(
+            $count_query = PhpMyAdmin\SqlParser\Utils\Query::replaceClause(
                 $analyzed_sql_results['statement'],
                 $analyzed_sql_results['parser']->list,
                 'SELECT SQL_CALC_FOUND_ROWS',
@@ -1196,7 +1202,7 @@ function PMA_countQueryResults(
 function PMA_executeTheQuery($analyzed_sql_results, $full_sql_query, $is_gotofile,
     $db, $table, $find_real_end, $sql_query_for_bookmark, $extra_data
 ) {
-    $response = PMA\libraries\Response::getInstance();
+    $response = Response::getInstance();
     $response->getHeader()->getMenu()->setTable($table);
 
     // Only if we ask to see the php code
@@ -1227,7 +1233,7 @@ function PMA_executeTheQuery($analyzed_sql_results, $full_sql_query, $is_gotofil
         // If there are no errors and bookmarklabel was given,
         // store the query as a bookmark
         if (! empty($_POST['bkm_label']) && ! empty($sql_query_for_bookmark)) {
-            $cfgBookmark = PMA_Bookmark_getParams();
+            $cfgBookmark = Bookmark::getParams();
             PMA_storeTheQueryAsBookmark(
                 $db, $cfgBookmark['user'],
                 $sql_query_for_bookmark, $_POST['bkm_label'],
@@ -1265,8 +1271,8 @@ function PMA_executeTheQuery($analyzed_sql_results, $full_sql_query, $is_gotofil
         );
 
         if (isset($_REQUEST['dropped_column'])
-            && mb_strlen($db)
-            && mb_strlen($table)
+            && strlen($db) > 0
+            && strlen($table) > 0
         ) {
             // to refresh the list of indexes (Ajax mode)
             $extra_data['indexes_list'] = PMA\libraries\Index::getHtmlForIndexes(
@@ -1293,7 +1299,7 @@ function PMA_deleteTransformationInfo($db, $table, $analyzed_sql_results)
 {
     include_once 'libraries/transformations.lib.php';
     $statement = $analyzed_sql_results['statement'];
-    if ($statement instanceof SqlParser\Statements\AlterStatement) {
+    if ($statement instanceof PhpMyAdmin\SqlParser\Statements\AlterStatement) {
         if (!empty($statement->altered[0])
             && $statement->altered[0]->options->has('DROP')
         ) {
@@ -1305,7 +1311,7 @@ function PMA_deleteTransformationInfo($db, $table, $analyzed_sql_results)
                 );
             }
         }
-    } elseif ($statement instanceof SqlParser\Statements\DropStatement) {
+    } elseif ($statement instanceof PhpMyAdmin\SqlParser\Statements\DropStatement) {
         PMA_clearTransformations($db, $table);
     }
 }
@@ -1336,7 +1342,7 @@ function PMA_getMessageForNoRowsReturned($message_to_show,
         if ($insert_id != 0) {
             // insert_id is id of FIRST record inserted in one insert,
             // so if we inserted multiple rows, we had to increment this
-            $message->addMessage('[br]');
+            $message->addText('[br]');
             // need to use a temporary because the Message class
             // currently supports adding parameters only to the first
             // message
@@ -1379,7 +1385,7 @@ function PMA_getMessageForNoRowsReturned($message_to_show,
 
     // In case of ROLLBACK, notify the user.
     if (isset($_REQUEST['rollback_query'])) {
-        $message->addMessage(__('[ROLLBACK occurred.]'));
+        $message->addText(__('[ROLLBACK occurred.]'));
     }
 
     return $message;
@@ -1428,6 +1434,10 @@ function PMA_getQueryResponseForNoResultsReturned($analyzed_sql_results, $db,
     }
 
     $html_output = '';
+    $html_message = PMA\libraries\Util::getMessage(
+        $message, $GLOBALS['sql_query'], 'success'
+    );
+    $html_output .= $html_message;
     if (!isset($GLOBALS['show_as_php'])) {
 
         if (! empty($GLOBALS['reload'])) {
@@ -1435,11 +1445,6 @@ function PMA_getQueryResponseForNoResultsReturned($analyzed_sql_results, $db,
             $extra_data['db'] = $GLOBALS['db'];
         }
 
-        $html_message = PMA\libraries\Util::getMessage(
-            $message, $GLOBALS['sql_query'], 'success'
-        );
-        $html_output .= $html_message;
-
         // For ajax requests add message and sql_query as JSON
         if (empty($_REQUEST['ajax_page_request'])) {
             $extra_data['message'] = $message;
@@ -1448,7 +1453,7 @@ function PMA_getQueryResponseForNoResultsReturned($analyzed_sql_results, $db,
             }
         }
 
-        $response = PMA\libraries\Response::getInstance();
+        $response = Response::getInstance();
         $response->addJSON(isset($extra_data) ? $extra_data : array());
 
         if (!empty($analyzed_sql_results['is_select']) &&
@@ -1476,7 +1481,7 @@ function PMA_getQueryResponseForNoResultsReturned($analyzed_sql_results, $db,
                 $analyzed_sql_results
             );
 
-            $cfgBookmark = PMA_Bookmark_getParams();
+            $cfgBookmark = Bookmark::getParams();
             if ($cfgBookmark) {
                 $html_output .= PMA_getHtmlForBookmark(
                     $displayParts,
@@ -1506,7 +1511,7 @@ function PMA_sendResponseForGridEdit($result)
     if (stristr($field_flags, PMA\libraries\DisplayResults::BINARY_FIELD)) {
         $row[0] = bin2hex($row[0]);
     }
-    $response = PMA\libraries\Response::getInstance();
+    $response = Response::getInstance();
     $response->addJSON('value', $row[0]);
     exit;
 }
@@ -1589,7 +1594,7 @@ function PMA_getHtmlForSqlQueryResultsTable($displayResultsObject,
     $editable, $unlim_num_rows, $num_rows, $showtable, $result,
     $analyzed_sql_results, $is_limited_display = false
 ) {
-    $printview = isset($_REQUEST['printview']) ? $_REQUEST['printview'] : null;
+    $printview = isset($_REQUEST['printview']) && $_REQUEST['printview'] == '1' ? '1' : null;
     $table_html = '';
     $browse_dist = ! empty($_REQUEST['is_browse_distinct']);
 
@@ -1847,33 +1852,41 @@ function PMA_getQueryResponseForResultsReturned($result, $analyzed_sql_results,
     $showtable = isset($showtable) ? $showtable : null;
     $url_query = isset($url_query) ? $url_query : null;
 
-    $response = PMA\libraries\Response::getInstance();
+    $response = Response::getInstance();
     $header   = $response->getHeader();
     $scripts  = $header->getScripts();
 
+    $just_one_table = PMA_resultSetHasJustOneTable($fields_meta);
+
     // hide edit and delete links:
     // - for information_schema
     // - if the result set does not contain all the columns of a unique key
     //   (unless this is an updatable view)
+    // - if the SELECT query contains a join or a subquery
 
     $updatableView = false;
 
     $statement = $analyzed_sql_results['statement'];
-    if ($statement instanceof SqlParser\Statements\SelectStatement) {
+    if ($statement instanceof PhpMyAdmin\SqlParser\Statements\SelectStatement) {
         if (!empty($statement->expr)) {
             if ($statement->expr[0]->expr === '*') {
                 $_table = new Table($table, $db);
                 $updatableView = $_table->isUpdatableView();
             }
         }
+
+        if ($analyzed_sql_results['join']
+            || $analyzed_sql_results['is_subquery']
+            || count($analyzed_sql_results['select_tables']) !== 1
+        ) {
+            $just_one_table = false;
+        }
     }
 
     $has_unique = PMA_resultSetContainsUniqueKey(
         $db, $table, $fields_meta
     );
 
-    $just_one_table = PMA_resultSetHasJustOneTable($fields_meta);
-
     $editable = ($has_unique
         || $GLOBALS['cfg']['RowActionLinksWithoutUnique']
         || $updatableView)
@@ -1889,7 +1902,7 @@ function PMA_getQueryResponseForResultsReturned($result, $analyzed_sql_results,
         'pview_lnk' => '1'
     );
 
-    if (!empty($table) && ($GLOBALS['dbi']->isSystemSchema($db) || !$editable)) {
+    if ($GLOBALS['dbi']->isSystemSchema($db) || !$editable) {
         $displayParts = array(
             'edit_lnk' => $displayResultsObject::NO_EDIT_OR_DELETE,
             'del_lnk' => $displayResultsObject::NO_EDIT_OR_DELETE,
@@ -1972,7 +1985,7 @@ function PMA_getQueryResponseForResultsReturned($result, $analyzed_sql_results,
         isset($selectedTables) ? $selectedTables : null, $db
     );
 
-    $cfgBookmark = PMA_Bookmark_getParams();
+    $cfgBookmark = Bookmark::getParams();
     if ($cfgBookmark) {
         $bookmark_support_html = PMA_getHtmlForBookmark(
             $displayParts,
@@ -2035,10 +2048,14 @@ function PMA_executeQueryAndSendQueryResponse($analyzed_sql_results,
         list(
             $analyzed_sql_results,
             $db,
-            $table
+            $table_from_sql
         ) = PMA_parseAnalyze($sql_query, $db);
         // @todo: possibly refactor
         extract($analyzed_sql_results);
+
+        if ($table != $table_from_sql && !empty($table_from_sql)) {
+            $table = $table_from_sql;
+        }
     }
 
     $html_output = PMA_executeQueryAndGetQueryResponse(
@@ -2062,7 +2079,7 @@ function PMA_executeQueryAndSendQueryResponse($analyzed_sql_results,
         $complete_query // complete_query
     );
 
-    $response = PMA\libraries\Response::getInstance();
+    $response = Response::getInstance();
     $response->addHTML($html_output);
 }
 
